@@ -96,8 +96,6 @@ class Question:
                 return
         except errors.ValidationError as e:
             raise e
-        except Exception:
-            pass
         raise errors.ValidationError(current)
 
     def _solve(self, prop, *args, **kwargs):
@@ -111,10 +109,11 @@ class Question:
 class Text(Question):
     kind = "text"
 
-    def __init__(self, name, message="", default=None, **kwargs):
+    def __init__(self, name, message="", default=None, autocomplete=None, **kwargs):
         super().__init__(
             name, message=message, default=str(default) if default and not callable(default) else default, **kwargs
         )
+        self.autocomplete = autocomplete
 
 
 class Password(Text):
@@ -140,22 +139,42 @@ class List(Question):
     kind = "list"
 
     def __init__(
-        self, name, message="", choices=None, default=None, ignore=False, validate=True, carousel=False, other=False
+        self,
+        name,
+        message="",
+        choices=None,
+        default=None,
+        ignore=False,
+        validate=True,
+        carousel=False,
+        other=False,
+        autocomplete=None,
     ):
 
         super().__init__(name, message, choices, default, ignore, validate, other=other)
         self.carousel = carousel
+        self.autocomplete = autocomplete
 
 
 class Checkbox(Question):
     kind = "checkbox"
 
     def __init__(
-        self, name, message="", choices=None, default=None, ignore=False, validate=True, carousel=False, other=False
+        self,
+        name,
+        message="",
+        choices=None,
+        default=None,
+        ignore=False,
+        validate=True,
+        carousel=False,
+        other=False,
+        autocomplete=None,
     ):
 
         super().__init__(name, message, choices, default, ignore, validate, other=other)
         self.carousel = carousel
+        self.autocomplete = autocomplete
 
 
 # Solution for checking valid path based on
@@ -176,7 +195,9 @@ def is_pathname_valid(pathname):
 
         root_dirname = os.environ.get("HOMEDRIVE", "C:") if sys.platform == "win32" else os.path.sep
 
-        assert os.path.isdir(root_dirname)
+        if not os.path.isdir(root_dirname):
+            raise Exception("'%s' is not a directory.", root_dirname)
+
         root_dirname = root_dirname.rstrip(os.path.sep) + os.path.sep
 
         for pathname_part in pathname.split(os.path.sep):
