@@ -89,27 +89,37 @@ class Default(Theme):
         self.Editor.opening_prompt_color = term.bright_black
         self.Checkbox.selection_color = term.blue
         self.Checkbox.selection_icon = ">"
-        self.Checkbox.selected_icon = "X"
+        self.Checkbox.selected_icon = "[X]"
         self.Checkbox.selected_color = term.yellow + term.bold
         self.Checkbox.unselected_color = term.normal
-        self.Checkbox.unselected_icon = "o"
+        self.Checkbox.unselected_icon = "[ ]"
         self.List.selection_color = term.blue
         self.List.selection_cursor = ">"
         self.List.unselected_color = term.normal
 
 
-class GreenPassion(Theme):
+class GreenPassion(Default):
     def __init__(self):
         super().__init__()
-        self.Question.mark_color = term.yellow
         self.Question.brackets_color = term.bright_green
-        self.Question.default_color = term.yellow
         self.Checkbox.selection_color = term.bold_black_on_bright_green
         self.Checkbox.selection_icon = "❯"
         self.Checkbox.selected_icon = "◉"
         self.Checkbox.selected_color = term.green
-        self.Checkbox.unselected_color = term.normal
         self.Checkbox.unselected_icon = "◯"
         self.List.selection_color = term.bold_black_on_bright_green
         self.List.selection_cursor = "❯"
-        self.List.unselected_color = term.normal
+
+
+class BlueComposure(Default):
+    def __init__(self):
+        super().__init__()
+        self.Question.brackets_color = term.dodgerblue
+        self.Question.default_color = term.deepskyblue2
+        self.Checkbox.selection_icon = "➤"
+        self.Checkbox.selection_color = term.bold_black_on_darkslategray3
+        self.Checkbox.selected_icon = "☒"
+        self.Checkbox.selected_color = term.cyan3
+        self.Checkbox.unselected_icon = "☐"
+        self.List.selection_color = term.bold_black_on_darkslategray3
+        self.List.selection_cursor = "➤"
